import { Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ChartConfiguration, ChartData, ChartType } from 'chart.js';
import { BaseChartDirective } from 'ng2-charts';
import { EnergyPrice } from '../energy-price.service';

@Component({
  selector: 'app-energy-chart',
  templateUrl: './energy-chart.component.html',
  styleUrls: ['./energy-chart.component.css'],
  standalone: true,
  imports: [CommonModule, BaseChartDirective]
})
export class EnergyChartComponent implements OnChanges {
  @Input() priceData: EnergyPrice[] = [];

  // Chart configuration
  public lineChartType: ChartType = 'line';

  public lineChartData: ChartData<'line'> = {
    datasets: [],
    labels: []
  };

  public lineChartOptions: ChartConfiguration['options'] = {
    responsive: true,
    maintainAspectRatio: false,
    scales: {
      x: {
        title: {
          display: true,
          text: 'Time'
        }
      },
      y: {
        title: {
          display: true,
          text: 'Price (SEK per kWh)'
        },
        beginAtZero: true
      }
    },
    plugins: {
      legend: {
        display: true,
      },
      tooltip: {
        callbacks: {
          label: function(context) {
            let label = context.dataset.label || '';
            if (label) {
              label += ': ';
            }
            if (context.parsed.y !== null) {
              label += context.parsed.y.toFixed(2) + ' SEK/kWh';
            }
            return label;
          }
        }
      }
    }
  };

  ngOnChanges(changes: SimpleChanges): void {
    if (changes['priceData'] && this.priceData) {
      this.updateChartData();
    }
  }

  private updateChartData(): void {
    // Extract time labels and price values
    const labels = this.priceData.map(item => {
      const startTime = new Date(item.time_start);
      return startTime.getHours() + ':00';
    });

    const sekPrices = this.priceData.map(item => item.SEK_per_kWh);
    const eurPrices = this.priceData.map(item => item.EUR_per_kWh);

    // Update chart data
    this.lineChartData = {
      labels: labels,
      datasets: [
        {
          data: sekPrices,
          label: 'SEK per kWh',
          backgroundColor: 'rgba(66, 133, 244, 0.2)',
          borderColor: 'rgb(66, 133, 244)',
          pointBackgroundColor: 'rgb(66, 133, 244)',
          fill: 'origin',
          tension: 0.4
        },
        {
          data: eurPrices,
          label: 'EUR per kWh',
          backgroundColor: 'rgba(15, 157, 88, 0.2)',
          borderColor: 'rgb(15, 157, 88)',
          pointBackgroundColor: 'rgb(15, 157, 88)',
          fill: 'origin',
          tension: 0.4
        }
      ]
    };
  }
}
